==> ACE+TAO-6.3.3.tar.bz2: ACE_wrappers/TAO/TAO_IDL/include/idl_defines.h <==
/*

COPYRIGHT

Copyright 1992, 1993, 1994 Sun Microsystems, Inc.  Printed in the United
States of America.  All Rights Reserved.

This product is protected by copyright and distributed under the following
license restricting its use.

The Interface Definition Language Compiler Front End (CFE) is made
available for your use provided that you include this license and copyright
notice on all media and documentation and the software program in which
this product is incorporated in whole or part. You may copy and extend
functionality (but may not remove functionality) of the Interface
Definition Language CFE without charge, but you are not authorized to
license or distribute it to anyone else except as part of a product or
program developed by you or with the express written consent of Sun
Microsystems, Inc. ("Sun").

The names of Sun Microsystems, Inc. and any of its subsidiaries or
affiliates may not be used in advertising or publicity pertaining to
distribution of Interface Definition Language CFE as permitted herein.

This license is effective until terminated by Sun for failure to comply
with this license.  Upon termination, you shall destroy or return all code
and documentation for the Interface Definition Language CFE.

INTERFACE DEFINITION LANGUAGE CFE IS PROVIDED AS IS WITH NO WARRANTIES OF
ANY KIND INCLUDING THE WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS
FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR ARISING FROM A COURSE OF
DEALING, USAGE OR TRADE PRACTICE.

INTERFACE DEFINITION LANGUAGE CFE IS PROVIDED WITH NO SUPPORT AND WITHOUT
ANY OBLIGATION ON THE PART OF Sun OR ANY OF ITS SUBSIDIARIES OR AFFILIATES
TO ASSIST IN ITS USE, CORRECTION, MODIFICATION OR ENHANCEMENT.

SUN OR ANY OF ITS SUBSIDIARIES OR AFFILIATES SHALL HAVE NO LIABILITY WITH
RESPECT TO THE INFRINGEMENT OF COPYRIGHTS, TRADE SECRETS OR ANY PATENTS BY
INTERFACE DEFINITION LANGUAGE CFE OR ANY PART THEREOF.

IN NO EVENT WILL SUN OR ANY OF ITS SUBSIDIARIES OR AFFILIATES BE LIABLE FOR
ANY LOST REVENUE OR PROFITS OR OTHER SPECIAL, INDIRECT AND CONSEQUENTIAL
DAMAGES, EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

Use, duplication, or disclosure by the government is subject to
restrictions as set forth in subparagraph (c)(1)(ii) of the Rights in
Technical Data and Computer Software clause at DFARS 252.227-7013 and FAR
52.227-19.

Sun, Sun Microsystems and the Sun logo are trademarks or registered
trademarks of Sun Microsystems, Inc.

SunSoft, Inc.
2550 Garcia Avenue
Mountain View, California  94043

NOTE:

SunOS, SunSoft, Sun, Solaris, Sun Microsystems or the Sun logo are
trademarks or registered trademarks of Sun Microsystems, Inc.

 */

#ifndef _IDL_DEFINES_IDL_DEFINES_HH
#define _IDL_DEFINES_IDL_DEFINES_HH

#include "ace/os_include/os_limits.h"

/*
 * idl_defines.hh - Defines global compiler flags
 */

// This cannot be an enum since more than one value may be active at
// a given time, hence bitflags are #define'd instead

// HP-UX 64-bit warns that the result of '<<' is widened from an int to long.
// They are assumed to be of type long within the tao_idl and IFR code.

#define IDL_CF_VERSION          (long)(1 << 0)
#define IDL_CF_DUMP_AST         (long)(1 << 1)
#define IDL_CF_ONLY_PREPROC     (long)(1 << 2)
#define IDL_CF_ONLY_USAGE       (long)(1 << 3)
#define IDL_CF_INFORMATIVE      (long)(1 << 4)
#define IDL_CF_NOWARNINGS       (long)(1 << 5)

#define NAMEBUFSIZE 1024
// Maximum length of static buffers used to store names.

#define SUN_IDL_FE_VERSION "1.3.0"

#if !defined (NFILES)
# define NFILES 2048
#endif /* ! NFILES */

#endif  // _IDL_DEFINES_IDL_DEFINES_HH

==> ACE+TAO-8.0.0.tar.bz2: ACE_wrappers/TAO/TAO_IDL/include/idl_defines.h <==
/*

COPYRIGHT

Copyright 1992, 1993, 1994 Sun Microsystems, Inc.  Printed in the United
States of America.  All Rights Reserved.

This product is protected by copyright and distributed under the following
license restricting its use.

The Interface Definition Language Compiler Front End (CFE) is made
available for your use provided that you include this license and copyright
notice on all media and documentation and the software program in which
this product is incorporated in whole or part. You may copy and extend
functionality (but may not remove functionality) of the Interface
Definition Language CFE without charge, but you are not authorized to
license or distribute it to anyone else except as part of a product or
program developed by you or with the express written consent of Sun
Microsystems, Inc. ("Sun").

The names of Sun Microsystems, Inc. and any of its subsidiaries or
affiliates may not be used in advertising or publicity pertaining to
distribution of Interface Definition Language CFE as permitted herein.

This license is effective until terminated by Sun for failure to comply
with this license.  Upon termination, you shall destroy or return all code
and documentation for the Interface Definition Language CFE.

INTERFACE DEFINITION LANGUAGE CFE IS PROVIDED AS IS WITH NO WARRANTIES OF
ANY KIND INCLUDING THE WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS
FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR ARISING FROM A COURSE OF
DEALING, USAGE OR TRADE PRACTICE.

INTERFACE DEFINITION LANGUAGE CFE IS PROVIDED WITH NO SUPPORT AND WITHOUT
ANY OBLIGATION ON THE PART OF Sun OR ANY OF ITS SUBSIDIARIES OR AFFILIATES
TO ASSIST IN ITS USE, CORRECTION, MODIFICATION OR ENHANCEMENT.

SUN OR ANY OF ITS SUBSIDIARIES OR AFFILIATES SHALL HAVE NO LIABILITY WITH
RESPECT TO THE INFRINGEMENT OF COPYRIGHTS, TRADE SECRETS OR ANY PATENTS BY
INTERFACE DEFINITION LANGUAGE CFE OR ANY PART THEREOF.

IN NO EVENT WILL SUN OR ANY OF ITS SUBSIDIARIES OR AFFILIATES BE LIABLE FOR
ANY LOST REVENUE OR PROFITS OR OTHER SPECIAL, INDIRECT AND CONSEQUENTIAL
DAMAGES, EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

Use, duplication, or disclosure by the government is subject to
restrictions as set forth in subparagraph (c)(1)(ii) of the Rights in
Technical Data and Computer Software clause at DFARS 252.227-7013 and FAR
52.227-19.

Sun, Sun Microsystems and the Sun logo are trademarks or registered
trademarks of Sun Microsystems, Inc.

SunSoft, Inc.
2550 Garcia Avenue
Mountain View, California  94043

NOTE:

SunOS, SunSoft, Sun, Solaris, Sun Microsystems or the Sun logo are
trademarks or registered trademarks of Sun Microsystems, Inc.

 */

#ifndef _IDL_DEFINES_IDL_DEFINES_HH
#define _IDL_DEFINES_IDL_DEFINES_HH

#include "tao/idl_features.h"

#include "ace/os_include/os_limits.h"

/*
 * idl_defines.hh - Defines global compiler flags
 */

// This cannot be an enum since more than one value may be active at
// a given time, hence bitflags are #define'd instead

// HP-UX 64-bit warns that the result of '<<' is widened from an int to long.
// They are assumed to be of type long within the tao_idl and IFR code.

#define IDL_CF_DUMP_AST         (long)(1 << 1)
#define IDL_CF_ONLY_PREPROC     (long)(1 << 2)
#define IDL_CF_INFORMATIVE      (long)(1 << 4)
#define IDL_CF_NOWARNINGS       (long)(1 << 5)

/**
 * IDL_CF_ONLY_USAGE is deprecated but remains for backwards compatibility.
 * It's direct successor is print_help (), but this was being used as part of
 * an indicator of a argument being invalid. Convention is that cli programs
 * only say that the argument(s) are wrong, not to print out the whole
 * help/usage message, so instead this call should be used:
 *   idl_global->parse_args_exit (1);
 *
 * When this is called, the argument parser should state the mistake and exit
 * the parsing early. Afterwards tao_idl will print how to see the help and
 * exit with an error status.
 */
#define IDL_CF_ONLY_USAGE       (long)(1 << 3)

/**
 * This signals that tao_idl has void idl_global->parse_args_exit (int status).
 * Use something like this to have backends use the new behavior with tao_idl
 * newer than 2.5.1 but still remain backwards compatible with older versions
 * of tao_idl:
 *   #ifdef TAO_IDL_HAS_PARSE_ARGS_EXIT
 *   #define PARSE_ARGS_ERROR idl_global->parse_args_exit (1);
 *   #else
 *   #define PARSE_ARGS_ERROR \
 *      idl_global->set_compile_flags ( \
 *        idl_global->compile_flags () | IDL_CF_ONLY_USAGE);
 *   #endif
 */
#define TAO_IDL_HAS_PARSE_ARGS_EXIT

#define NAMEBUFSIZE 1024
// Maximum length of static buffers used to store names.

#define SUN_IDL_FE_VERSION "1.3.0"

#if !defined (NFILES)
# define NFILES 2048
#endif /* ! NFILES */

#endif  // _IDL_DEFINES_IDL_DEFINES_HH
